import { useRef, useState, useCallback } from "react";
import dequal from "dequal";
import useInterval from "./useInterval";
import { UNKNOWN, OK, BAD, FAILED } from "../components/shared/StatusMessage";

export default (
  url,
  {
    ms = 20000,
    fetchOptions = {},
  } = {},
) => {
  const fetchOptsRef = useRef({});
  if (!dequal(fetchOptsRef.current, fetchOptions)) {
    fetchOptsRef.current = fetchOptions;
  }

  const [result, setResult] = useState([UNKNOWN, null]);
  const pollApi = useCallback(async () => {
    try {
      const res = await fetch(url, fetchOptsRef.current);
      const js = await res.json();
      if (res.ok) {
        setResult([OK, js]);
      } else {
        setResult([BAD, js]);
      }
    }
    catch (err) {
      setResult([FAILED, err]);
    }
  }, [url]);

  useInterval(pollApi, ms);

  return result;
}